{% load i18n %}


<div class="table-responsive">
    <table id="tbl-effective-requests" class="table table-striped table-width-fix">
        <thead>
            <tr>
                <th>{% translate "Date" %}</th>
                <th>{% translate "Contact Name" %}</th>
                <th>{% translate "Organization" %}</th>
                <th>{% translate "Main Character" %}</th>
                <th>{% translate "Scopes / State" %}</th>
                <th>{% translate "Effective / Accepted By" %}</th>
                <th>{% translate "Contact Labels" %}</th>
            </tr>
        </thead>
        <tbody>
        </tbody>
    </table>
</div>
