{% load i18n %}

<tr>
    <td
        class="text-muted"
        colspan="9"
        style="text-align: left; vertical-align: middle;">
        {% translate "No Pending or approved requests." %}
    </td>
</tr>
