{% extends 'altcorp/base.html' %}
{% load i18n %}
{% load humanize %}
{% load static %}
{% load evelinks %}

{% block altcorp_body %}
        <h2>{% translate "My Requests" %}</h2>
    <p class="text-muted">
        {% blocktranslate  %}
            <p>On this page you can create requests to add your alt corp to the alt alliance:<bold> {{alliance}} </bold>.</p>
            <p>All characters in the alt corp must be owned by a member and registered in this auth.</p>
        {% endblocktranslate %}
    </p>

    <div class="panel panel-default">
        <div class="panel-body">
            <div hx-get="{% url 'altcorp:request_corporations' %}" hx-trigger="load">
                {% include "altcorp/partials/spinner.html" %}
            </div>
        </div>
    </div>

    <br>
    <div class="panel panel-default">
        <div class="panel-heading">{% translate "Icon Legend" %}</div>
        <div class="panel-body">
            <table class="table">
                <tr>
                    <td>
                        <i class="fas fa-star fa-fw text-primary"></i>
                    </td>
                    <td>
                        {% translate "Corporation is in the alt alliance." %}
                    </td>
                </tr>
                <tr>
                    <td>
                        <i class="fas fa-exclamation-triangle fa-fw text-warning"></i>
                    </td>
                    <td>
                        {% translate "Your corporation has failed the requirement check! you have until the shown date to resolve the issue, or your alt corp will be removed." %}
                    </td>
                </tr>
                <tr>
                    <td>
                        <i class="fas fa-hourglass-start fa-fw"></i>
                    </td>
                    <td>
                        {% translate "Your alt corp request is pending approval." %}
                    </td>
                </tr>
                <tr>
                    <td>
                        <i class="fas fa-hourglass-half fa-fw text-success"></i>
                    </td>
                    <td>
                        {% translate "Your alt corp request has been approved, but is waiting for confirmation that it has joined the alt alliance." %}
                    </td>
                </tr>
                <tr>
                    <td>
                        <i class="fas fa-reply-all fa-fw text-danger"></i>
                    </td>
                    <td>
                        {% translate "Your alt corp has failed to resolve passed the deadline for resolving requirement issues and will be removed from the alt alliance." %}
                    </td>
                </tr>
                <tr>
                    <td>
                        <i class="fas fa-info-circle fa-fw text-info"></i>
                    </td>
                    <td>
                        {% translate "Characters are missing from auth, please add them." %}
                    </td>
                </tr>
            </table>
        </div>
    </div>

{% endblock %}

{% block extra_css %}
    {{ block.super }}
    <link rel="stylesheet" href="{% static 'altcorp/css/create_requests.css' %}" type="text/css" media="screen">
{% endblock extra_css %}
