# Generated by Django 4.2.17 on 2025-04-07 22:50

# Django
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("altcorp", "0001_initial"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="general",
            options={
                "default_permissions": (),
                "managed": False,
                "permissions": (
                    ("access_app", "Can access this app and make a request"),
                    ("manage_requests", "Can manage alt corp requests."),
                ),
            },
        ),
    ]
